import 'package:basf_logic_components/domain/models/barcode_id.dart';
import 'package:basf_logic_components/domain/models/barcode_info.dart';
import 'package:gs1_barcode_parser/gs1_barcode_parser.dart';

class BarcodeData {
  const BarcodeData({
    required this.code,
    this.barcodeId,
    this.gs1barcode,
    this.information,
  });

  final BarcodeId? barcodeId;
  final String code;
  final GS1Barcode? gs1barcode;
  final List<BarcodeInfo>? information;

  BarcodeData copyWith({
    String? code,
    BarcodeId? barcodeId,
    List<BarcodeInfo>? information,
  }) {
    return BarcodeData(
      code: code ?? this.code,
      barcodeId: barcodeId ?? this.barcodeId,
      information: information ?? this.information,
    );
  }

  Map<String, dynamic> toJson() {
    return {
      'codeId': code,
      'information': information?.map((e) => e.toJson()).toList(),
    };
  }

  factory BarcodeData.fromJson(Map<String, dynamic> json) {
    return BarcodeData(
      code: json['codeId'],
      information: (json['information'] as List<dynamic>?)
          ?.map((e) => BarcodeInfo.fromJson(e as Map<String, dynamic>))
          .toList(),
    );
  }
}
