import 'dart:async';

import 'package:basf_logic_components/basf_logic_components.dart';
import 'package:collection/collection.dart';
import 'package:gs1_barcode_parser/gs1_barcode_parser.dart';

extension QuntityWithUnit on ScanData {
  ({double? quantity, String? unit}) get quantityWithUnit {
    double? returnQuantity;
    String? returnUnit;
    if (netWeightKg != null) {
      returnQuantity = netWeightKg;
      returnUnit = 'KG';
    } else if (netWeightPounds != null) {
      returnQuantity = netWeightPounds;
      returnUnit = 'LB';
    } else if (lengthMeters != null) {
      returnQuantity = lengthMeters;
      returnUnit = 'M';
    } else if (widthMeters != null) {
      returnQuantity = widthMeters;
      returnUnit = 'M';
    } else if (depthMeters != null) {
      returnQuantity = depthMeters;
      returnUnit = 'M';
    } else if (areaSqMeters != null) {
      returnQuantity = areaSqMeters;
      returnUnit = 'M2';
    } else if (volumeLitres != null) {
      returnQuantity = volumeLitres;
      returnUnit = 'L';
    } else if (volumeCubicMeters != null) {
      returnQuantity = volumeCubicMeters;
      returnUnit = 'M3';
    } else if (quantity != null) {
      returnQuantity = quantity;
    }
    return (quantity: returnQuantity, unit: returnUnit);
  }
}

extension ParseExtension on List<GS1ParsedElement> {
  dynamic valueForExactKey(GS1AICodes code) {
    return firstWhereOrNull((e) => e.aiCode == code.code)?.data;
  }

  dynamic valueForKeyStartingWith(GS1AICodes code) {
    return firstWhereOrNull((e) => e.aiCode.startsWith(code.code))?.data;
  }
}

extension StreamDebounce<T> on Stream<T> {
  Stream<T> debounceTime(Duration duration) {
    Timer? timer;
    return transform(StreamTransformer.fromHandlers(
      handleData: (T data, EventSink<T> sink) {
        timer?.cancel();
        timer = Timer(duration, () => sink.add(data));
      },
      handleDone: (EventSink<T> sink) {
        timer?.cancel();
        sink.close();
      },
    ));
  }
}
